==> hbase-client-1.4.3-sources.jar: org/apache/hadoop/hbase/NotServingRegionException.java <==
/**
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase;

import org.apache.hadoop.hbase.classification.InterfaceAudience;
import org.apache.hadoop.hbase.classification.InterfaceStability;
import org.apache.hadoop.hbase.util.Bytes;

import java.io.IOException;

/**
 * Thrown by a region server if it is sent a request for a region it is not
 * serving.
 */
@InterfaceAudience.Public
@InterfaceStability.Stable
public class NotServingRegionException extends IOException {
  private static final long serialVersionUID = (1L << 17) - 1L;

  /** default constructor */
  public NotServingRegionException() {
    super();
  }

  /**
   * Constructor
   * @param s message
   */
  public NotServingRegionException(String s) {
    super(s);
  }

  /**
   * Constructor
   * @param s message
   */
  public NotServingRegionException(final byte [] s) {
    super(Bytes.toString(s));
  }
}

==> hbase-client-2.1.3-sources.jar: org/apache/hadoop/hbase/NotServingRegionException.java <==
/**
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase;

import java.io.IOException;

import org.apache.yetus.audience.InterfaceAudience;
import org.apache.hadoop.hbase.util.Bytes;

/**
 * Thrown by a region server if it is sent a request for a region it is not
 * serving.
 */
@InterfaceAudience.Public
public class NotServingRegionException extends IOException {
  private static final long serialVersionUID = (1L << 17) - 1L;

  /** default constructor */
  public NotServingRegionException() {
    super();
  }

  /**
   * Constructor
   * @param s message
   */
  public NotServingRegionException(String s) {
    super(s);
  }

  /**
   * Constructor
   * @param s message
   */
  public NotServingRegionException(final byte [] s) {
    super(Bytes.toString(s));
  }
}
